# -*- coding: utf-8 -*-

"""
legit.core
~~~~~~~~~~

This module provides the basic functionality of legit.
"""

# from clint import resources

__version__ = '0.0.9'
__author__ = 'Kenneth Reitz'
__license__ = 'BSD'


# resources.init('kennethreitz', 'legit')
# resources.user.write('config.ini', "we'll get there.")